@@ -34,7 +34,7 @@
 #' @details
 #' When `method="simulation"`, we conduct simulation-based inference following the method discussed in Krinsky & Robb (1986):
 #' 1. Draw `R` sets of simulated coefficients from a multivariate normal distribution with mean equal to the original model's estimated coefficients and variance equal to the model's variance-covariance matrix (classical, "HC3", or other).
-#' 2. Use the `R` sets of coefficients to compute `R` sets of estimands: predictions, comparisons, or slopes.
+#' 2. Use the `R` sets of coefficients to compute `R` sets of estimands: predictions, comparisons, slopes, or hypotheses.
 #' 3. Take quantiles of the resulting distribution of estimands to obtain a confidence interval and the standard deviation of simulated estimates to estimate the standard error.
 #'
 #' When `method="fwb"`, drawn weights are supplied to the model fitting function's `weights` argument; if the model doesn't accept non-integer weights, this method should not be used. If weights were included in the original model fit, they are extracted by [weights()] and multiplied by the drawn weights. These weights are supplied to the `wts` argument of the estimation function (e.g., `comparisons()`).
@@ -96,7 +96,8 @@ inferences <- function(x,
     checkmate::assert(
         checkmate::check_class(x, "predictions"),
         checkmate::check_class(x, "comparisons"),
-        checkmate::check_class(x, "slopes")
+        checkmate::check_class(x, "slopes"),
+        checkmate::check_class(x, "hypotheses")
     )
     checkmate::assert_number(conf_level, lower = 1e-10, upper = 1 - 1e-10)
     checkmate::assert_integerish(R, lower = 2)
@@ -186,14 +187,14 @@ inferences <- function(x,
 }
 
 
-inferences_dispatch <- function(model, FUN, ...) {
+inferences_dispatch <- function(model, INF_FUN, ...) {
     if (isTRUE(attr(model, "inferences_method") == "rsample")) {
-        bootstrap_rsample(model = model, FUN = FUN, ...)
+        bootstrap_rsample(model = model, INF_FUN = INF_FUN, ...)
     } else if (isTRUE(attr(model, "inferences_method") == "boot")) {
-        bootstrap_boot(model = model, FUN = FUN, ...)
+        bootstrap_boot(model = model, INF_FUN = INF_FUN, ...)
     } else if (isTRUE(attr(model, "inferences_method") == "fwb")) {
-        bootstrap_fwb(model = model, FUN = FUN, ...)
+        bootstrap_fwb(model = model, INF_FUN = INF_FUN, ...)
     } else {
         return(NULL)
     }
-}
\ No newline at end of file
+}
