@@ -1,8 +1,7 @@
 source("helpers.R")
-exit_if_not(require("tinyviztest"))
-exit_if_not(!ON_OSX)
-using("tinyviztest")
 using("marginaleffects")
+if (!requiet("tinysnapshot")) exit_file("tinysnapshot")
+using("tinysnapshot")
 
 mod <- lm(mpg ~ hp * factor(gear), mtcars)
 expect_snapshot_print(predictions(mod), "print-predictions")
@@ -12,8 +11,6 @@ expect_snapshot_print(predictions(mod, by = "gear"), "print-predictions_by")
 # expect_snapshot_print(comparisons(mod), "print-comparisons")
 expect_snapshot_print(comparisons(mod, by = "gear"), "print-comparisons_by")
 
-expect_snapshot_print(marginal_means(mod, "gear"), "print-marginal_means")
-
 
 # Issue #638: keep datagrid() explicit variables in print
 dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/Stat2Data/Titanic.csv")
@@ -24,10 +21,14 @@ expect_snapshot_print(p, "print-predictions_datagrid")
 
 # twitter Kurz request
 mod <- lm(mpg ~ hp + am, data = mtcars)
-    comparisons(mod, variables = "am", newdata = data.frame(am = 0:1, hp = 120))
+
 expect_snapshot_print(
     comparisons(mod, variables = "am", newdata = data.frame(am = 0:1, hp = 120)),
-    "print-comparisons_1focal")
+    "print-comparisons_1focal_dataframe")
+
+expect_snapshot_print(
+    comparisons(mod, variables = "am", newdata = datagrid(am = 0:1, hp = 120)),
+    "print-comparisons_1focal_datagrid")
 
 expect_snapshot_print(
     predictions(mod, newdata = data.frame(am = 0:1, hp = 120)),
